%p = ( January   => 'Janeiro',
       February  => 'Fevereiro',
       March     => 'Março',
       April     => 'Abril',
       May       => 'Maio',
       June      => 'Junho',
       July      => 'Julho',
       August    => 'Agosto',
       September => 'Setembro',
       October   => 'Outubro',
       November  => 'Novembro',
       December  => 'Dezembro' );

chomp ($d = `date +"%d de %B de %Y"`);
foreach $month (keys %p) {
  $d =~ s/$month/$p{$month}/;
}
$v = pop @ARGV;
while (<>) {
 s/^Versão.+/Versão~$v, $d/;
 print;
}
